@@ -1,5 +1,5 @@
 use {
-  super::{subprocess::SubprocCommand, types::Fail},
+  super::{subprocess::SubprocCommand, types::Die},
   aho_corasick::{AhoCorasick, AhoCorasickBuilder},
   clap::Parser,
   regex::{Regex, RegexBuilder},
@@ -7,6 +7,7 @@ use {
   std::{
     collections::HashMap,
     env::{args_os, current_dir, var_os},
+    ffi::OsString,
     io::{stderr, stdout, IsTerminal},
     path::PathBuf,
   },
@@ -84,22 +85,24 @@ pub struct Arguments {
   pub unified: Option<usize>,
 }
 
+fn parse_fzf_mode(argv: &OsString) -> Option<Mode> {
+  let exec = argv
+    .to_str()
+    .unwrap_or_default()
+    .split('\x04')
+    .collect::<Vec<_>>();
+  match exec[..] {
+    [Mode::PREVIEW, path] => Some(Mode::Preview(PathBuf::from(path))),
+    [Mode::PATCH, path] => Some(Mode::Patch(PathBuf::from(path))),
+    _ => None,
+  }
+}
+
 pub fn parse_args() -> (Mode, Arguments) {
   let args = args_os().collect::<Vec<_>>();
   match (
     args.get(1).and_then(|a| a.to_str()),
-    args.get(2).and_then(|a| {
-      let exec = a
-        .to_str()
-        .unwrap_or_default()
-        .split('\x04')
-        .collect::<Vec<_>>();
-      match exec[..] {
-        [Mode::PREVIEW, path] => Some(Mode::Preview(PathBuf::from(path))),
-        [Mode::PATCH, path] => Some(Mode::Patch(PathBuf::from(path))),
-        _ => None,
-      }
-    }),
+    args.get(2).and_then(parse_fzf_mode),
     var_os(Mode::ARGV).and_then(|a| a.into_string().ok()),
   ) {
     (Some("-c"), Some(mode), Some(arg_list)) => {
@@ -152,14 +155,14 @@ fn p_auto_flags(exact: bool, pattern: &str) -> Vec<String> {
   flags
 }
 
-fn p_aho_corasick(pattern: &str, flags: Vec<String>) -> Result<AhoCorasick, Fail> {
+fn p_aho_corasick(pattern: &str, flags: Vec<String>) -> Result<AhoCorasick, Die> {
   let mut ac = AhoCorasickBuilder::new();
   for flag in flags {
     match flag.as_str() {
       "i" => ac.ascii_case_insensitive(true),
       "I" => ac.ascii_case_insensitive(false),
       _ => {
-        return Err(Fail::ArgumentError(format!(
+        return Err(Die::ArgumentError(format!(
           "Invalid regex flag, see `--help` :: {flag}"
         )))
       }
@@ -168,7 +171,7 @@ fn p_aho_corasick(pattern: &str, flags: Vec<String>) -> Result<AhoCorasick, Fail
   Ok(ac.build([pattern])?)
 }
 
-fn p_regex(pattern: &str, flags: Vec<String>) -> Result<Regex, Fail> {
+fn p_regex(pattern: &str, flags: Vec<String>) -> Result<Regex, Die> {
   let mut re = RegexBuilder::new(pattern);
   for flag in flags {
     match flag.as_str() {
@@ -183,7 +186,7 @@ fn p_regex(pattern: &str, flags: Vec<String>) -> Result<Regex, Fail> {
       "x" => re.ignore_whitespace(true),
       "X" => re.ignore_whitespace(false),
       _ => {
-        return Err(Fail::ArgumentError(format!(
+        return Err(Die::ArgumentError(format!(
           "Invalid regex flag, see `--help` :: {flag}"
         )))
       }
@@ -240,7 +243,7 @@ fn p_pager(pager: &Option<String>) -> Option<SubprocCommand> {
   })
 }
 
-pub fn parse_opts(mode: Mode, args: Arguments) -> Result<Options, Fail> {
+pub fn parse_opts(mode: Mode, args: Arguments) -> Result<Options, Die> {
   let mut flagset = p_auto_flags(args.exact, &args.pattern);
   flagset.extend(
     args
