@@ -1,5 +1,5 @@
 use {
-  super::types::Fail,
+  super::types::Die,
   std::{borrow::ToOwned, fs::Metadata, io::ErrorKind, path::Path},
   tokio::{
     fs::{rename, File, OpenOptions},
@@ -13,22 +13,22 @@ pub struct Slurpee {
   pub content: String,
 }
 
-pub async fn slurp(path: &Path) -> Result<Slurpee, Fail> {
+pub async fn slurp(path: &Path) -> Result<Slurpee, Die> {
   let mut fd = File::open(path)
     .await
-    .map_err(|e| Fail::IO(path.to_owned(), e.kind()))?;
+    .map_err(|e| Die::IO(path.to_owned(), e.kind()))?;
 
   let meta = fd
     .metadata()
     .await
-    .map_err(|e| Fail::IO(path.to_owned(), e.kind()))?;
+    .map_err(|e| Die::IO(path.to_owned(), e.kind()))?;
 
   let content = if meta.is_file() {
     let mut s = String::default();
     match fd.read_to_string(&mut s).await {
       Ok(_) => s,
       Err(err) if err.kind() == ErrorKind::InvalidData => s,
-      Err(err) => return Err(Fail::IO(path.to_owned(), err.kind())),
+      Err(err) => return Err(Die::IO(path.to_owned(), err.kind())),
     }
   } else {
     String::default()
@@ -37,7 +37,7 @@ pub async fn slurp(path: &Path) -> Result<Slurpee, Fail> {
   Ok(Slurpee { meta, content })
 }
 
-pub async fn spit(canonical: &Path, meta: &Metadata, text: &str) -> Result<(), Fail> {
+pub async fn spit(canonical: &Path, meta: &Metadata, text: &str) -> Result<(), Die> {
   let uuid = Uuid::new_v4().as_simple().to_string();
   let mut file_name = canonical
     .file_name()
@@ -52,25 +52,25 @@ pub async fn spit(canonical: &Path, meta: &Metadata, text: &str) -> Result<(), F
     .write(true)
     .open(&tmp)
     .await
-    .map_err(|e| Fail::IO(tmp.clone(), e.kind()))?;
+    .map_err(|e| Die::IO(tmp.clone(), e.kind()))?;
   fd.set_permissions(meta.permissions())
     .await
-    .map_err(|e| Fail::IO(tmp.clone(), e.kind()))?;
+    .map_err(|e| Die::IO(tmp.clone(), e.kind()))?;
 
   let mut writer = BufWriter::new(fd);
   writer
     .write_all(text.as_bytes())
     .await
-    .map_err(|e| Fail::IO(tmp.clone(), e.kind()))?;
+    .map_err(|e| Die::IO(tmp.clone(), e.kind()))?;
 
   writer
     .flush()
     .await
-    .map_err(|e| Fail::IO(tmp.clone(), e.kind()))?;
+    .map_err(|e| Die::IO(tmp.clone(), e.kind()))?;
 
   rename(&tmp, &canonical)
     .await
-    .map_err(|e| Fail::IO(canonical.to_owned(), e.kind()))?;
+    .map_err(|e| Die::IO(canonical.to_owned(), e.kind()))?;
 
   Ok(())
 }
